==> IceWarpServer-10.0.8_RHEL5.tar.gz: html/webmail/client/inc/obj_sip.js <==
_me = obj_sip.prototype;
function obj_sip(){};

_me.__constructor = function(){

	if (currentBrowser() != 'Mozilla'){
	    this._main.style.position = 'absolute';
	    this._main.style.top = 0;
	    this._main.style.left = 0;
	    this._main.style.zIndex = 1000;
    }

	this._main.style.width = '1px';
	this._main.style.height = '1px';
	
	this.__playSounds = true;
	this.__callBuffer = [];

	//Destructor
	this._add_destructor('__destructor');

	this.__init();
};

_me.__init = function (){
	if (this.__timeout)
		clearInterval(this.__timeout);

	try{
		if (this.__applet)
			this.__applet.destroy();
	}
	catch(r){}

	if (!navigator.javaEnabled())
        gui._create('sip_error','frm_alert','','','','SIP::ERROR','',getLang('SIP::NOJAVA'));
	else{
		if (currentBrowser() != 'MSIE7' && currentBrowser() != 'Mozilla')
	        gui._create('sip_error','frm_alert','','','','SIP::ERROR','',getLang('SIP::NOSUPPORT'));

		this._main.style.visibility = 'visible';
		this._main.innerHTML = '<applet code="com.icewarp.control.Controller.class" codebase="'+ document.getElementsByTagName('base')[0].href +'client/inc/sip/" archive="sip_call_signed.jar" name="SIP Java Client 1.1" width="1" MAYSCRIPT height="1"></applet>';

		if ((this.__applet = this._main.getElementsByTagName('applet')[0])){
			var me = this;
			this.__timeout = window.setInterval(function(){me.__onload();},2000);
		}
		else
			this._main.style.visibility = 'hidden';
	}
};

_me.__onload = function (v){
	if (this.__applet){
		if (typeof this.__applet.isActive == 'undefined'){
            window.clearInterval(this.__timeout);
			try{
				this._main.removeChild(this.__applet);
			}
			catch(e){}
			
			this._destruct();
		}
		else
		if (this.__applet.isActive()){
            window.clearInterval(this.__timeout);

			//interval is fired twice sometime in MSIE
			if (this._getStatus())
				return;

			try{
				if (GWOthers.getItem('SIP','external')>0 && GWOthers.getItem('RESTRICTIONS', 'disable_esip')<1 && GWOthers.getItem('SIP','server') && GWOthers.getItem('SIP','user') && GWOthers.getItem('SIP','pass'))
					this.__applet.readParams(GWOthers.getItem('SIP','server'), GWOthers.getItem('SIP','user'), GWOthers.getItem('SIP','pass'), 55, this.__playSounds, this._pathName, '__process');
				else
					this.__applet.readParams(document.location.host, dataSet.get('main',['account']), null, 55, this.__playSounds, this._pathName, '__process');
			}
			catch(r){
	            this.__applet.destroy();
			}

			//hide applet block
			this._main.style.visibility = 'hidden';
		}
	}
};

_me._login = function (){
	try{
		if (this.__applet && this.__applet.isActive && this.__applet.isActive() && this._getStatus()!='failed'){
			if (GWOthers.getItem('SIP','external')>0 && GWOthers.getItem('RESTRICTIONS', 'disable_esip')<1 && GWOthers.getItem('SIP','server') && GWOthers.getItem('SIP','user') && GWOthers.getItem('SIP','pass'))
				this.__applet.login(55, GWOthers.getItem('SIP','server'), GWOthers.getItem('SIP','user'), GWOthers.getItem('SIP','pass'));
			else
				this.__applet.login(55, document.location.host, dataSet.get('main',['account']), null);
		}
		else
		    throw true;
	}
	catch(r){
		this.__init();
	}
};

_me._logout = function (){
	if (this.__applet && typeof this.__applet.isActive != 'undefined' && this.__applet.isActive())
		this.__applet.logout();
};

// CALLBACK
_me._add_callbeck = function (aHandler){
	var tmp = getCallbackFunction(aHandler);
	for(var i = this.__callBuffer.length-1; i>=0; i--)
		if (getCallbackFunction(this.__callBuffer[i])===tmp)
			return;

	this.__callBuffer.push(aHandler);
};
_me._execute = function (aData){
	for(var i = this.__callBuffer.length-1; i>=0; i--){
		if (getCallbackFunction(this.__callBuffer[i]))
			executeCallbackFunction(this.__callBuffer[i],aData);
		else
			this.__callBuffer.splice(i,1);
	}
};

/*
 *   parametr type     | vyznam udalosti                              | param1                                      |   param2
 *   __________________|______________________________________________|_____________________________________________|____________
 *   IncomingCall      | oznameni prichoziho hovoru                   | emailova adresa volajiciho                  |
 *   CallEstablished   | hovor zacal (vysila a prijima se RTP stream) | Informace o tom s kym se vola               |
 *   UserBusy          | volany ucastnik je nedostupny                | Informace, ze uzivatel ma obsazeno          |
 *   CallFinished      | Hovor skoncil                                | Informace o ukonceni hovoru                 |
 *   CallCanceled      | Hovor byl zrusen                             | Informace o zruseni hovoru druhym uzivatelem|
 *   Notification      | Notifikace o stavu kontaktu z contactlistu   | adresa kontaktu (napr. mzukal@icewarp.com)  | status
 *   Info              | Informace (napr. uspesna registrace)         | iformacni text                              |
 *   Authenticate      | Zadost o provedeni autentizace               | nonce (viz RFC 2617)                        | H(A2)
 *   Exception         | Vyjimka                                      | popis nastale chyby                         |
 *   Error             | spatne nastavene prostredi (napr. neni JMF)  | JMF nebo UDP nebo JMF,UDP
 */
_me.__process = function (sType, sParam1, sParam2, sParam3){

	var sValue = sParam1;

	//Error nejde odchytit pres switch :)
	if (sType == 'Error'){
		//hide applet block
		this._main.style.visibility = 'hidden';

        var str = '';
		if (sParam1 == 'server'){
			str = getLang('SIP::UNREACHABLE');
			dataSet.add('sip',['info'],getLang('SIP::OFFLINE'));
		}
		else{
			var arr = sParam1.split(',');
			for (var i = 0;i<arr.length;i++)
				str += (str?'<hr size="1">':'') + getLang('SIP::' + arr[i]);
		}

		gui._create('sip_error','frm_alert','','','','SIP::ERROR','',str);

 		return;
	}
	
	switch (sType.toString()){
	case 'Authenticate':
		auth.get_digest({hash:sParam1,command:sParam2,uri:sParam3},'SIP',[this,'__authenticate']);
		return;

	case 'Exception':
		this.__init();
		return;

	case 'IncomingCall':
		//vytvorit dialog
		gui._create('call', 'frm_call', '', '', sParam1, false, sParam2=='true');
		sValue = getLang('SIP::INCOMINGCALL',[sParam1]);
		break;
	case 'CallEstablished':
		sValue = getLang('SIP::CALLESTABLISHED',[sParam1]);
		if (sParam2 == 'true')
			gui._create('call', 'frm_call', '', '', sParam1, true);
		break;
	case 'UserBusy':
		sValue = getLang('SIP::USERBUSY',[sParam1]);
		break;
	case 'CallFinished':
		sValue = getLang('SIP::CALLFINISHED',[sParam1]);
		break;
	case 'CallCanceled':
		sValue = getLang('SIP::CALLCANCELED',[sParam1]);
		break;
	case 'Info':
		sValue = getLang('SIP::INFO',[sParam1]);
		break;
	case 'RegistrationEvent':
		switch(sParam2){
		case 'online':
			sValue = getLang('SIP::REGISTRATION1',[sParam1]);
			break;
		case 'offline':
			sValue = getLang('SIP::OFFLINE');
			break;
		case 'timeout':
		case 'failed':
			sValue = getLang('SIP::REGISTRATION0',[sParam1]);
			break;
		}

		break;
	case 'Notification':
		sValue = getLang('SIP::NOTIFICATION',[sParam1,sParam2]);
		if (sParam1 == this.__lastCalled && sParam2 == 'offline')
			this._hangup();

		break;
	default:
		sValue = sType+': '+sParam1;
	}

	dataSet.add('sip',['info'],sValue,true);
	dataSet.add('sip',['type'],sType,true);
	dataSet.update('sip');
	
	this._execute({type:sType,value:sValue,p1:sParam1,p2:sParam2});
};


/**
 * Funkce, ktera inicializuje hovor na predanou adresu pripadne tel. cislo
 * @param address adresa uzivatele, kteremu se ma volat
 * */
_me._call = function(address,bVideo) {
	if (this.__applet.isActive()){

		if (address.indexOf('@')<0){
			//External account
			if (GWOthers.getItem('SIP','external')>0 && GWOthers.getItem('RESTRICTIONS', 'disable_esip')<1){
				if (GWOthers.getItem('SIP','server'))
					address += '@' + GWOthers.getItem('SIP','server');
			}
			else
				address += '@'+dataSet.get('main',['domain']);
		}
		
		this.__lastCalled = address;
		
		this.__applet.makeCall(address,bVideo || false,bVideo || false);
	}
};


/**
 * Funkce zajisti korektni ukonceni hovoru
 * */
_me._hangup = function() {
	this.__lastCalled = '';

	if (this.__applet.isActive())
		this.__applet.hangUp();
};


/**
 * Funkce ma byt volana v pripade, ze se uzivatel rozhodne prijmout hovor
 * */
_me._answerCall = function(bVideo) {
	this.__lastCalled = '';

	if (this.__applet.isActive())
		this.__applet.acceptCall(bVideo || false,bVideo || false);
};


/**
 * Funkce ma byt volana v pripade, ze se uzivatel rozhodne odmitnout hovor
 * */
_me._declineCall = function() {
	if (this.__applet.isActive())
		this.__applet.declineCall();
};


/**
 * Funkce slouzici pro odeslani odpovedi na REGISTER zpravu.
 * Odpoved musi obsahovat retezec response (parametr funkce),
 * ktery je vypocten podle algoritmu uvedeneho v RFC 2617.
 * @param response vypocteny response string
 *
 *
response se vypocita takhle:
response = KD(H(A1), nonce + ":" + H(A2));
s tim, ze A1 je:
A1 = username + ":" + realm + ":" + password; (realm je server napr. icewarp.com)
H je hashovani md5 a KD je spojeni retezcu, ktery se zhashuje.

 **/
_me.__authenticate = function(response) {
	if (this.__applet.isActive())
		this.__applet.setResponse(response);
};


/**
 * Funkce zajistuje posilani SIP zpravy SUBSCRIBE na zadane cislo nebo email.
 * Zprava SUBSCRIBE zajistuje, ze vzdaleny kontakt bude informovat uzivatele o zmene
 * statusu pripadne o dalsich potrebnych udalostech.
 * Jako odpoved na zpravu SUBSCRIBE je posilana zprava NOTIFY, ve ktere kontakt
 * posila informace o aktualnim stavu.
 * Tyto informace jsou do webmailu predany pres funkci __processEvent
 * s parametrem param1 Notification.
 * Zprava SUBSCRIBE je pak posilana v pravidelnych intervalech tak, aby
 * subscription nevyprselo.
 * @param address adresa uzivatele, kteremu ma byt poslana zprava SUBSCRIBE
 *
_me._subscribe = function(address) {
    if (this.__applet.isActive())
		this.__applet.sendSubscribe(address);
};
*/
/**
 * Funkci je vhodne pouzit pri odstraneni uzivatele z contactlistu.
 * Funkce zajisti ukonceni posilani zprav NOTIFY od uzivatele se zadanou adresou
 * a odstrani tuto adresu z fronty pro posilani SUBSCRIBE zprav.
 * Pozor pokud je druhym klientem wengo, tato metoda nepracuje spravne,
 * protoze wengo se nechova podle RFC.
 * @param address adresa uzivatele, ktery ma byt odstranen
 *
_me._cancelSubscription = function(address) {
    if (this.__applet.isActive())
		this.__applet.removeSubscription(address);
};
*/
/**
 * Funkci lze pouzit pro zmenu statusu prihlaseneho uzivatele.
 * Funkce zajisti, ze vsem kontaktum, ktere maji aktivni subscription
 * je odeslana zprava NOTIFY, v jejimz tele jsou ulozeny informace
 * o novem stavu.
 * @param status napr. Away, Busy apod.
 *
_me._changeStatus = function(status) {
    if (this.__applet.isActive())
		this.__applet.statusChange(status);
};
*/
/**
 * Metoda pro ziskani aktualniho stavu appletu.
 * @return retezec popisujici stav
 * Moznosti jsou nasledujici
 * pokud uzivatel prave vola vraci "Calling"
 * pokud uzivatel ma prichozi hovor, ale jeste jej nezvedl ani neodmitl vraci "Call pending"
 * pokud neplati ani jedna z predchozich podminek vraci stav nastaveny pomoci metody changeStatus
 * */
_me._getStatus = function(bNoInit) {
	var tmp = false;
	if (!this.__applet || typeof this.__applet.isActive == 'undefined'){
		if (!bNoInit)
			this.__init();
		else
			return 'offline';
	}
	else
	if (this.__applet.isActive()){
		try{
			tmp = this.__applet.getState() || 'failed';
		}
		catch(e){}
	}

	return tmp;
};

/**
 * Metoda pro získání úrovně hlasitosti. Pokud nebyla předem úroveň hlasitosti
 * nastavena vrací číslo -1, jinak vrací to, co bylo nastaveno.
 * @return celé číslo mezi 0 a 100
 * */
_me._getVolume = function() {
	if (this.__applet.isActive())
		var result = this.__applet.getVolume();
};

/**
 * Metoda pro nastavení úrovně hlasitosti. Touto funkcí je ovlivněna pouze
 * hlasitost přenášeného hlasu a nikoli hlasitost přehrávaných zvuků.
 * @param ratio celé číslo mezi 0 100
 * */
_me._setVolume = function(ratio) {
	if (this.__applet.isActive())
		this.__applet.setVolume(ratio);
};

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
_me.__destructor = function (){
	var stat = this._getStatus(true);
	if (stat && stat!='offline')
		this._logout();
};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/obj_sip.js <==
_me = obj_sip.prototype;
function obj_sip(){};

_me.__constructor = function(){

	if (currentBrowser() != 'Mozilla'){
	    this._main.style.position = 'absolute';
	    this._main.style.top = 0;
	    this._main.style.left = 0;
	    this._main.style.zIndex = 1000;
    }

	this._main.style.width = '1px';
	this._main.style.height = '1px';
	
	this.__playSounds = true;
	this.__callBuffer = [];

	//Destructor
	this._add_destructor('__destructor');

	this.__init();
};

_me.__init = function (){
	if (this.__timeout)
		clearInterval(this.__timeout);

	try{
		if (this.__applet){
			this.__applet.destroy();
			this.__applet.parentNode.removeChild(this.__applet);
		}
	}
	catch(r){}
	this.__applet = null;

	if (!navigator.javaEnabled()){
		gui._create('sip_error','frm_alert','','','','SIP::ERROR','',getLang('SIP::NOJAVA'));
		this._destruct();
    }
	else{
		if (currentBrowser() != 'MSIE7' && currentBrowser() != 'Mozilla')
	        gui._create('sip_error','frm_alert','','','','SIP::ERROR','',getLang('SIP::NOSUPPORT'));

		this._main.style.visibility = 'visible';
		this._main.innerHTML = '<applet code="com.icewarp.control.Controller.class" codebase="'+ document.getElementsByTagName('base')[0].href +'client/inc/sip/" archive="sip_call_signed.jar" name="SIP Java Client 1.1" width="1" MAYSCRIPT height="1"></applet>';

		if ((this.__applet = this._main.getElementsByTagName('applet')[0])){
			var me = this;
			this.__timeout = window.setInterval(function(){me.__onload();},1000);
		}
		else
			this._main.style.visibility = 'hidden';
	}
};

_me.__onload = function (v){
	if (this.__applet){
		if (typeof this.__applet.isActive == 'undefined'){
            window.clearInterval(this.__timeout);
			/*
			try{
				this._main.removeChild(this.__applet);
			}
			catch(e){}
			*/
			this._destruct();
		}
		else
		if (this.__applet.isActive()){
            window.clearInterval(this.__timeout);

			//interval is fired twice sometime in MSIE
			if (this._getStatus())
				return;

			try{
				if (GWOthers.getItem('SIP','external')>0 && (GWOthers.getItem('RESTRICTIONS', 'disable_esip') || 0)<1 && GWOthers.getItem('SIP','server') && GWOthers.getItem('SIP','user') && GWOthers.getItem('SIP','pass'))
					this.__applet.readParams(GWOthers.getItem('SIP','server'), GWOthers.getItem('SIP','user'), GWOthers.getItem('SIP','pass'), 55, this.__playSounds, this._pathName, '__process');
				else
					this.__applet.readParams(document.location.host, dataSet.get('main',['account']), null, 55, this.__playSounds, this._pathName, '__process');
			}
			catch(r){
	            this.__applet.destroy();
			}

			//hide applet block
			this._main.style.visibility = 'hidden';
		}
	}
};

_me._login = function (){
	try{
		if (this.__applet && this.__applet.isActive && this.__applet.isActive() && this._getStatus()!='failed'){
			if (GWOthers.getItem('SIP','external')>0 && (GWOthers.getItem('RESTRICTIONS', 'disable_esip') || 0)<1 && GWOthers.getItem('SIP','server') && GWOthers.getItem('SIP','user') && GWOthers.getItem('SIP','pass'))
				this.__applet.login(55, GWOthers.getItem('SIP','server'), GWOthers.getItem('SIP','user'), GWOthers.getItem('SIP','pass'));
			else
				this.__applet.login(55, document.location.host, dataSet.get('main',['account']), null);
		}
		else
		    throw true;
	}
	catch(r){
		this.__init();
	}
};

_me._logout = function (){
	if (this.__applet && typeof this.__applet.isActive != 'undefined' && this.__applet.isActive()){
        if (this._getStatus() == 'Calling')
			this._hangup();
			
		this.__applet.logout();
	}
};

// CALLBACK
_me._add_callbeck = function (aHandler){
	var tmp = getCallbackFunction(aHandler);
	for(var i = this.__callBuffer.length-1; i>=0; i--)
		if (getCallbackFunction(this.__callBuffer[i])===tmp)
			return;

	this.__callBuffer.push(aHandler);
};
_me._execute = function (aData){
	for(var i = this.__callBuffer.length-1; i>=0; i--){
		if (getCallbackFunction(this.__callBuffer[i]))
			executeCallbackFunction(this.__callBuffer[i],aData);
		else
			this.__callBuffer.splice(i,1);
	}
};

/*
 *   parametr type     | vyznam udalosti                              | param1                                      |   param2
 *   __________________|______________________________________________|_____________________________________________|____________
 *   IncomingCall      | oznameni prichoziho hovoru                   | emailova adresa volajiciho                  |
 *   CallEstablished   | hovor zacal (vysila a prijima se RTP stream) | Informace o tom s kym se vola               |
 *   UserBusy          | volany ucastnik je nedostupny                | Informace, ze uzivatel ma obsazeno          |
 *   CallFinished      | Hovor skoncil                                | Informace o ukonceni hovoru                 |
 *   CallCanceled      | Hovor byl zrusen                             | Informace o zruseni hovoru druhym uzivatelem|
 *   Notification      | Notifikace o stavu kontaktu z contactlistu   | adresa kontaktu (napr. mzukal@icewarp.com)  | status
 *   Info              | Informace (napr. uspesna registrace)         | iformacni text                              |
 *   Authenticate      | Zadost o provedeni autentizace               | nonce (viz RFC 2617)                        | H(A2)
 *   Exception         | Vyjimka                                      | popis nastale chyby                         |
 *   Error             | spatne nastavene prostredi (napr. neni JMF)  | JMF nebo UDP nebo JMF,UDP
 */
_me.__process = function (sType, sParam1, sParam2, sParam3){

	var sValue = sParam1;

	//Error nejde odchytit pres switch :)
	if (sType == 'Error'){
		//hide applet block
		this._main.style.visibility = 'hidden';

        var str = '';
		if (sParam1 == 'server'){
			str = getLang('SIP::UNREACHABLE');
			dataSet.add('sip',['info'],getLang('SIP::OFFLINE'));
		}
		else{
			var arr = sParam1.split(',');
			for (var i = 0;i<arr.length;i++)
				str += (str?'<hr size="1">':'') + getLang('SIP::' + arr[i]);
		}

		gui._create('sip_error','frm_alert','','','','SIP::ERROR','',str);

 		return;
	}
	
	switch (sType.toString()){
	case 'Authenticate':
		auth.get_digest({hash:sParam1,command:sParam2,uri:sParam3},'SIP',[this,'__authenticate']);
		return;

	case 'Exception':
		this.__init();
		return;

	case 'IncomingCall':
		//vytvorit dialog
		gui._create('call', 'frm_call', '', '', sParam1, false, sParam2=='true');
		sValue = getLang('SIP::INCOMINGCALL',[sParam1]);
		break;
	case 'CallEstablished':
		sValue = getLang('SIP::CALLESTABLISHED',[sParam1]);
		if (sParam2 == 'true')
			gui._create('call', 'frm_call', '', '', sParam1, true);
		break;
	case 'UserBusy':
		sValue = getLang('SIP::USERBUSY',[sParam1]);
		break;
	case 'CallFinished':
		sValue = getLang('SIP::CALLFINISHED',[sParam1]);
		break;
	case 'CallCanceled':
		sValue = getLang('SIP::CALLCANCELED',[sParam1]);
		break;
	case 'Info':
		sValue = getLang('SIP::INFO',[sParam1]);
		break;
	case 'RegistrationEvent':
		switch(sParam2){
		case 'online':
			sValue = getLang('SIP::REGISTRATION1',[sParam1]);
			break;
		case 'offline':
			sValue = getLang('SIP::OFFLINE');
			break;
		case 'timeout':
		case 'failed':
			sValue = getLang('SIP::REGISTRATION0',[sParam1]);
			break;
		}

		break;
	case 'Notification':
		sValue = getLang('SIP::NOTIFICATION',[sParam1,sParam2]);
		if (sParam1 == this.__lastCalled && sParam2 == 'offline')
			this._hangup();

		break;
	default:
		sValue = sType+': '+sParam1;
	}

	dataSet.add('sip',['info'],sValue,true);
	dataSet.add('sip',['type'],sType,true);
	dataSet.update('sip');
	
	this._execute({type:sType,value:sValue,p1:sParam1,p2:sParam2});
};


/**
 * Funkce, ktera inicializuje hovor na predanou adresu pripadne tel. cislo
 * @param address adresa uzivatele, kteremu se ma volat
 * */
_me._call = function(address,bVideo) {
	if (this.__applet.isActive()){

		if (address.indexOf('@')<0){
			//External account
			if (GWOthers.getItem('SIP','external')>0 && (GWOthers.getItem('RESTRICTIONS', 'disable_esip') || 0)<1){
				if (GWOthers.getItem('SIP','server'))
					address += '@' + GWOthers.getItem('SIP','server');
			}
			else
				address += '@'+dataSet.get('main',['domain']);
		}
		
		this.__lastCalled = address;
		
		this.__applet.makeCall(address,bVideo || false,bVideo || false);
	}
};

_me._dtmf = function(sChar){
	if (this.__applet.isActive() && sChar)
		this.__applet.sendDTMF(sChar);
};

/**
 * Funkce zajisti korektni ukonceni hovoru
 * */
_me._hangup = function() {
	this.__lastCalled = '';

	if (this.__applet.isActive())
		this.__applet.hangUp();
};


/**
 * Funkce ma byt volana v pripade, ze se uzivatel rozhodne prijmout hovor
 * */
_me._answerCall = function(bVideo) {
	this.__lastCalled = '';

	if (this.__applet.isActive())
		this.__applet.acceptCall(bVideo || false,bVideo || false);
};


/**
 * Funkce ma byt volana v pripade, ze se uzivatel rozhodne odmitnout hovor
 * */
_me._declineCall = function() {
	if (this.__applet.isActive())
		this.__applet.declineCall();
};


/**
 * Funkce slouzici pro odeslani odpovedi na REGISTER zpravu.
 * Odpoved musi obsahovat retezec response (parametr funkce),
 * ktery je vypocten podle algoritmu uvedeneho v RFC 2617.
 * @param response vypocteny response string
 *
 *
response se vypocita takhle:
response = KD(H(A1), nonce + ":" + H(A2));
s tim, ze A1 je:
A1 = username + ":" + realm + ":" + password; (realm je server napr. icewarp.com)
H je hashovani md5 a KD je spojeni retezcu, ktery se zhashuje.

 **/
_me.__authenticate = function(response) {
	if (this.__applet.isActive())
		this.__applet.setResponse(response);
};


/**
 * Funkce zajistuje posilani SIP zpravy SUBSCRIBE na zadane cislo nebo email.
 * Zprava SUBSCRIBE zajistuje, ze vzdaleny kontakt bude informovat uzivatele o zmene
 * statusu pripadne o dalsich potrebnych udalostech.
 * Jako odpoved na zpravu SUBSCRIBE je posilana zprava NOTIFY, ve ktere kontakt
 * posila informace o aktualnim stavu.
 * Tyto informace jsou do webmailu predany pres funkci __processEvent
 * s parametrem param1 Notification.
 * Zprava SUBSCRIBE je pak posilana v pravidelnych intervalech tak, aby
 * subscription nevyprselo.
 * @param address adresa uzivatele, kteremu ma byt poslana zprava SUBSCRIBE
 *
_me._subscribe = function(address) {
    if (this.__applet.isActive())
		this.__applet.sendSubscribe(address);
};
*/
/**
 * Funkci je vhodne pouzit pri odstraneni uzivatele z contactlistu.
 * Funkce zajisti ukonceni posilani zprav NOTIFY od uzivatele se zadanou adresou
 * a odstrani tuto adresu z fronty pro posilani SUBSCRIBE zprav.
 * Pozor pokud je druhym klientem wengo, tato metoda nepracuje spravne,
 * protoze wengo se nechova podle RFC.
 * @param address adresa uzivatele, ktery ma byt odstranen
 *
_me._cancelSubscription = function(address) {
    if (this.__applet.isActive())
		this.__applet.removeSubscription(address);
};
*/
/**
 * Funkci lze pouzit pro zmenu statusu prihlaseneho uzivatele.
 * Funkce zajisti, ze vsem kontaktum, ktere maji aktivni subscription
 * je odeslana zprava NOTIFY, v jejimz tele jsou ulozeny informace
 * o novem stavu.
 * @param status napr. Away, Busy apod.
 *
_me._changeStatus = function(status) {
    if (this.__applet.isActive())
		this.__applet.statusChange(status);
};
*/
/**
 * Metoda pro ziskani aktualniho stavu appletu.
 * @return retezec popisujici stav
 * Moznosti jsou nasledujici
 * pokud uzivatel prave vola vraci "Calling"
 * pokud uzivatel ma prichozi hovor, ale jeste jej nezvedl ani neodmitl vraci "Call pending"
 * pokud neplati ani jedna z predchozich podminek vraci stav nastaveny pomoci metody changeStatus
 * */
_me._getStatus = function(bNoInit) {
	var tmp = false;
	if (!this.__applet || typeof this.__applet.isActive == 'undefined'){
		if (!bNoInit)
			this.__init();
		else
			return 'offline';
	}
	else
	if (this.__applet.isActive()){
		try{
			tmp = this.__applet.getState() || 'failed';
		}
		catch(e){}
	}

	return tmp;
};

/**
 * Metoda pro získání úrovně hlasitosti. Pokud nebyla předem úroveň hlasitosti
 * nastavena vrací číslo -1, jinak vrací to, co bylo nastaveno.
 * @return celé číslo mezi 0 a 100
 * */
_me._getVolume = function() {
	if (this.__applet.isActive())
		var result = this.__applet.getVolume();
};

/**
 * Metoda pro nastavení úrovně hlasitosti. Touto funkcí je ovlivněna pouze
 * hlasitost přenášeného hlasu a nikoli hlasitost přehrávaných zvuků.
 * @param ratio celé číslo mezi 0 100
 * */
_me._setVolume = function(ratio) {
	if (this.__applet.isActive())
		this.__applet.setVolume(ratio);
};

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
_me.__destructor = function (){
	var stat = this._getStatus(true);
	if (stat && stat!='offline')
		this._logout();

	try{
		if (this.__applet){
			this.__applet.destroy();
			this.__applet.parentNode.removeChild(this.__applet);
		}
	}
	catch(r){}
	this.__applet = null;
};
